@@ -1,45 +1,48 @@
+/* -*- mode: C; indent-tabs-mode: t; tab-width: 8; c-basic-offset: 2; -*- */
+
 /*
  * This file is part of Seed, the GObject Introspection<->Javascript bindings.
  *
- * Seed is free software: you can redistribute it and/or modify 
+ * Seed is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as
  * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version. 
- * Seed is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
- * GNU Lesser General Public License for more details. 
- * You should have received a copy of the GNU Lesser General Public License 
- * along with Seed.  If not, see <http://www.gnu.org/licenses/>. 
+ * the License, or (at your option) any later version.
+ * Seed is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with Seed.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) Robert Carr 2008 <carrr@rpi.edu>
+ * Copyright (C) Robert Carr 2009 <carrr@rpi.edu>
  */
 
 #include <unistd.h>
 #include "seed-private.h"
 #include <sys/mman.h>
 #include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include <signal.h>
 
+JSValueRef seed_print_ref;
+JSValueRef seed_printerr_ref;
+
 static JSValueRef
 seed_include (JSContextRef ctx,
 	      JSObjectRef function,
 	      JSObjectRef this_object,
 	      size_t argumentCount,
-	      const JSValueRef arguments[], 
-	      JSValueRef * exception)
+	      const JSValueRef arguments[], JSValueRef * exception)
 {
   JSStringRef file_contents, file_name;
+
   GDir *dir;
   gchar *import_file, *abs_path;
   gchar *buffer, *walk;
-  guint i;
+  guint i, len;
 
   if (argumentCount != 1)
     {
-      seed_make_exception (ctx, exception, "ArgumentError", 
+      seed_make_exception (ctx, exception, "ArgumentError",
 			   "Seed.include expected 1 argument, "
 			   "got %zd", argumentCount);
       return JSValueMakeNull (ctx);
@@ -52,7 +55,8 @@ seed_include (JSContextRef ctx,
     g_file_get_contents (import_file, &buffer, 0, NULL);
   else				/* A search path is set and path given is not absolute.  */
     {
-      for (i = 0; i < g_strv_length (eng->search_path); ++i)
+      len = g_strv_length (eng->search_path);
+      for (i = 0; i < len; ++i)
 	{
 	  dir = g_dir_open (eng->search_path[i], 0, NULL);
 
@@ -65,6 +69,7 @@ seed_include (JSContextRef ctx,
 	  if (g_file_get_contents (abs_path, &buffer, 0, NULL))
 	    {
 	      g_free (abs_path);
+	      g_dir_close (dir);
 	      break;
 	    }
 
@@ -75,7 +80,7 @@ seed_include (JSContextRef ctx,
 
   if (!buffer)
     {
-      seed_make_exception (ctx, exception, "FileNotFound", 
+      seed_make_exception (ctx, exception, "FileNotFound",
 			   "File not found: %s", import_file);
 
       g_free (import_file);
@@ -113,8 +118,7 @@ seed_scoped_include (JSContextRef ctx,
 		     JSObjectRef function,
 		     JSObjectRef this_object,
 		     size_t argumentCount,
-		     const JSValueRef arguments[], 
-		     JSValueRef * exception)
+		     const JSValueRef arguments[], JSValueRef * exception)
 {
   JSContextRef nctx;
   JSObjectRef global;
@@ -126,7 +130,7 @@ seed_scoped_include (JSContextRef ctx,
 
   if (argumentCount != 1)
     {
-      seed_make_exception (ctx, exception, "ArgumentError", 
+      seed_make_exception (ctx, exception, "ArgumentError",
 			   "Seed.include expected 1 argument, "
 			   "got %zd", argumentCount);
       return JSValueMakeNull (ctx);
@@ -137,7 +141,7 @@ seed_scoped_include (JSContextRef ctx,
   /* just try current dir if no path set, or use the absolute path */
   if (!eng->search_path || g_path_is_absolute (import_file))
     g_file_get_contents (import_file, &buffer, 0, NULL);
-  else	/* A search path is set and path given is not absolute.  */
+  else				/* A search path is set and path given is not absolute.  */
     {
       for (i = 0; i < g_strv_length (eng->search_path); ++i)
 	{
@@ -162,9 +166,9 @@ seed_scoped_include (JSContextRef ctx,
 
   if (!buffer)
     {
-      seed_make_exception (ctx, exception, "FileNotFound", 
+      seed_make_exception (ctx, exception, "FileNotFound",
 			   "File not found: %s", import_file);
-      
+
       g_free (import_file);
       g_free (buffer);
       return JSValueMakeNull (ctx);
@@ -185,14 +189,14 @@ seed_scoped_include (JSContextRef ctx,
   file_contents = JSStringCreateWithUTF8CString (walk);
   file_name = JSStringCreateWithUTF8CString (import_file);
 
-  
+
   nctx = JSGlobalContextCreateInGroup (context_group, 0);
   seed_prepare_global_context (nctx);
 
   JSEvaluateScript (nctx, file_contents, NULL, file_name, 0, exception);
-  
-  global = JSContextGetGlobalObject(nctx);
-  
+
+  global = JSContextGetGlobalObject (nctx);
+
   JSGlobalContextRelease ((JSGlobalContextRef) nctx);
 
   JSStringRelease (file_contents);
@@ -210,31 +214,60 @@ seed_print (JSContextRef ctx,
 	    size_t argumentCount,
 	    const JSValueRef arguments[], JSValueRef * exception)
 {
+  gchar *buf;
   if (argumentCount != 1)
     {
-      seed_make_exception (ctx, exception, "ArgumentError", 
-			   "Seed.print expected 1 argument, got %zd", 
+      seed_make_exception (ctx, exception, "ArgumentError",
+			   "print expected 1 argument, got %zd",
 			   argumentCount);
       return JSValueMakeNull (ctx);
     }
 
-  gchar *buf = seed_value_to_string (ctx, arguments[0], exception);
+  buf = seed_value_to_string (ctx, arguments[0], exception);
+
   puts (buf);
   g_free (buf);
 
   return JSValueMakeUndefined (ctx);
 }
 
+static JSValueRef
+seed_printerr (JSContextRef ctx,
+	       JSObjectRef function,
+	       JSObjectRef this_object,
+	       size_t argumentCount,
+	       const JSValueRef arguments[],
+	       JSValueRef *exception)
+{
+  gchar *buf;
+  if (argumentCount != 1)
+    {
+      seed_make_exception (ctx, exception, "ArgumentError",
+			   "printerr expected 1 argument, got %zd",
+			   argumentCount);
+      return JSValueMakeNull (ctx);
+    }
+
+  buf = seed_value_to_string (ctx, arguments[0], exception);
+
+  g_printerr ("%s\n", buf);
+  g_free (buf);
+
+  return JSValueMakeUndefined (ctx);
+}
+
 const gchar *
 seed_g_type_name_to_string (GITypeInfo * type)
 {
   GITypeTag type_tag = g_type_info_get_tag (type);
 
   const gchar *type_name;
+  GIBaseInfo *interface;
 
   if (type_tag == GI_TYPE_TAG_INTERFACE)
     {
-      GIBaseInfo *interface = g_type_info_get_interface (type);
+      interface = g_type_info_get_interface (type);
+
       type_name = g_base_info_get_name (interface);
       g_base_info_unref (interface);
     }
@@ -256,12 +289,12 @@ seed_introspect (JSContextRef ctx,
   // TODO: LEAKY!
 
   GICallableInfo *info;
-  JSObjectRef data_obj, args_obj;
-  guint i;
+  JSObjectRef data_obj, args_obj, argument;
+  guint i, nargs;
 
   if (argumentCount != 1)
     {
-      seed_make_exception (ctx, exception, "ArgumentError", 
+      seed_make_exception (ctx, exception, "ArgumentError",
 			   "Seed.introspect expected 1 argument, "
 			   "got %zd", argumentCount);
       return JSValueMakeNull (ctx);
@@ -290,9 +323,10 @@ seed_introspect (JSContextRef ctx,
 
   seed_object_set_property (ctx, data_obj, "args", args_obj);
 
-  for (i = 0; i < g_callable_info_get_n_args (info); ++i)
+  nargs = g_callable_info_get_n_args (info);
+  for (i = 0; i < nargs; ++i)
     {
-      JSObjectRef argument = JSObjectMake (ctx, NULL, NULL);
+      argument = JSObjectMake (ctx, NULL, NULL);
 
       const gchar *arg_name =
 	seed_g_type_name_to_string (g_arg_info_get_type
@@ -315,11 +349,11 @@ seed_check_syntax (JSContextRef ctx,
 		   size_t argumentCount,
 		   const JSValueRef arguments[], JSValueRef * exception)
 {
+  JSStringRef jsstr;
   if (argumentCount == 1)
     {
-      JSStringRef jsstr = JSValueToStringCopy (ctx,
-					       arguments[0],
-					       exception);
+      jsstr = JSValueToStringCopy (ctx, arguments[0], exception);
+
       JSCheckScriptSyntax (ctx, jsstr, 0, 0, exception);
       if (jsstr)
 	JSStringRelease (jsstr);
@@ -333,19 +367,6 @@ seed_check_syntax (JSContextRef ctx,
   return JSValueMakeNull (ctx);
 }
 
-static JSValueRef
-seed_fork (JSContextRef ctx,
-	   JSObjectRef function,
-	   JSObjectRef this_object,
-	   size_t argumentCount,
-	   const JSValueRef arguments[], JSValueRef * exception)
-{
-  pid_t child;
-
-  child = fork ();
-  return seed_value_from_int (ctx, child, exception);
-}
-
 static JSValueRef
 seed_spawn (JSContextRef ctx,
 	    JSObjectRef function,
@@ -353,7 +374,7 @@ seed_spawn (JSContextRef ctx,
 	    size_t argumentCount,
 	    const JSValueRef arguments[], JSValueRef * exception)
 {
-  gchar *line, *stdout, *stderr;
+  gchar *line, *stdoutstr, *stderrstr;
   JSObjectRef ret;
   GError *error = NULL;
 
@@ -366,7 +387,7 @@ seed_spawn (JSContextRef ctx,
     }
 
   line = seed_value_to_string (ctx, arguments[0], exception);
-  g_spawn_command_line_sync (line, &stdout, &stderr, NULL, &error);
+  g_spawn_command_line_sync (line, &stdoutstr, &stderrstr, NULL, &error);
   if (error)
     {
       seed_make_exception_from_gerror (ctx, exception, error);
@@ -378,13 +399,15 @@ seed_spawn (JSContextRef ctx,
 
   ret = JSObjectMake (ctx, NULL, NULL);
   seed_object_set_property (ctx, ret, "stdout",
-			    seed_value_from_string (ctx, stdout, exception));
+			    seed_value_from_string (ctx, stdoutstr,
+						    exception));
   seed_object_set_property (ctx, ret, "stderr",
-			    seed_value_from_string (ctx, stderr, exception));
+			    seed_value_from_string (ctx, stderrstr,
+						    exception));
 
   g_free (line);
-  g_free (stdout);
-  g_free (stderr);
+  g_free (stdoutstr);
+  g_free (stderrstr);
 
   return ret;
 }
@@ -402,7 +425,7 @@ seed_quit (JSContextRef ctx,
     }
   else if (argumentCount > 1)
     {
-      seed_make_exception (ctx, exception, "ArgumentError", 
+      seed_make_exception (ctx, exception, "ArgumentError",
 			   "Seed.quit expected " "1 argument, got %zd",
 			   argumentCount);
     }
@@ -417,35 +440,34 @@ seed_breakpoint (JSContextRef ctx,
 		 size_t argumentCount,
 		 const JSValueRef arguments[], JSValueRef * exception)
 {
-  G_BREAKPOINT();
+  G_BREAKPOINT ();
   return JSValueMakeUndefined (ctx);
 }
 
 
 static JSValueRef
 seed_argv_get_property (JSContextRef ctx,
-			   JSObjectRef object,
-			   JSStringRef property_name, 
-			   JSValueRef * exception)
+			JSObjectRef object,
+			JSStringRef property_name, JSValueRef * exception)
 {
   SeedArgvPrivates *priv;
   gchar *cproperty_name;
-  gint length;
-  gint index;
-  
+  gsize length;
+  guint index;
+
   priv = JSObjectGetPrivate (object);
   if (!priv->argc)
     return JSValueMakeUndefined (ctx);
   length = JSStringGetMaximumUTF8CStringSize (property_name);
   cproperty_name = g_alloca (length * sizeof (gchar));
   JSStringGetUTF8CString (property_name, cproperty_name, length);
-  
-  if (!strcmp (cproperty_name, "length"))
+
+  if (!g_strcmp0 (cproperty_name, "length"))
     {
       return seed_value_from_int (ctx, priv->argc, exception);
     }
   index = atoi (cproperty_name);
-  return seed_value_from_string (ctx, priv->argv[index], exception);  
+  return seed_value_from_string (ctx, priv->argv[index], exception);
 }
 
 JSClassDefinition seed_argv_def = {
@@ -481,19 +503,32 @@ seed_init_builtins (SeedEngine * local_eng, gint * argc, gchar *** argv)
 					    "Seed");
 
   seed_create_function (local_eng->context, "include", &seed_include, obj);
-  seed_create_function (local_eng->context, "scoped_include", 
+  seed_create_function (local_eng->context, "scoped_include",
 			&seed_scoped_include, obj);
-  seed_create_function (local_eng->context, "print", &seed_print, obj);
+
+  seed_print_ref =
+    JSObjectMakeFunctionWithCallback (local_eng->context, NULL, &seed_print);
+  seed_object_set_property (local_eng->context, obj, "print", seed_print_ref);
+  seed_object_set_property (local_eng->context, local_eng->global, "print",
+			    seed_print_ref);
+  JSValueProtect (local_eng->context, seed_print_ref);
+
+  seed_printerr_ref =
+    JSObjectMakeFunctionWithCallback (local_eng->context, NULL, &seed_printerr);
+  seed_object_set_property (local_eng->context, obj, "printerr", seed_printerr_ref);
+  seed_object_set_property (local_eng->context, local_eng->global, "printerr",
+			    seed_printerr_ref);
+  JSValueProtect (local_eng->context, seed_printerr_ref);
+
   seed_create_function (local_eng->context,
 			"check_syntax", &seed_check_syntax, obj);
   seed_create_function (local_eng->context,
 			"introspect", &seed_introspect, obj);
-  seed_create_function (local_eng->context, "fork", &seed_fork, obj);
   seed_create_function (local_eng->context, "spawn", &seed_spawn, obj);
   seed_create_function (local_eng->context, "quit", &seed_quit, obj);
   seed_create_function (local_eng->context, "breakpoint",
 			&seed_breakpoint, obj);
-  
+
   priv = g_new0 (SeedArgvPrivates, 1);
   priv->argv = argv ? *argv : 0;
   priv->argc = argc ? *argc : 0;
@@ -502,5 +537,5 @@ seed_init_builtins (SeedEngine * local_eng, gint * argc, gchar *** argv)
   arrayObj = JSObjectMake (local_eng->context, seed_argv_class, priv);
 
   seed_object_set_property (local_eng->context, obj, "argv", arrayObj);
-  
+
 }
